@@ -98,4 +98,13 @@ VISIBLE = "visible"
 TRANSPARENT = "transparent"
 STRETCH = "stretch"
 LEFT = "left"
-RIGHT = "right"
\ No newline at end of file
+RIGHT = "right"
+
+FOLLOWING= "+"
+DESCENDANT=" "
+COMBINE=","
+CHILD=">"
+PRECEDING="~"
+
+CLASS_PREFIX = "."
+ID_PREFIX = "#"
\ No newline at end of file
